<?php
/*
 *                    ....
 *                  .:   '':.
 *                  ::::     ':..
 *                  ::.         ''..
 *       .:'.. ..':.:::'    . :.   '':.
 *      :.   ''     ''     '. ::::.. ..:
 *      ::::.        ..':.. .''':::::  .
 *      :::::::..    '..::::  :. ::::  :
 *      ::'':::::::.    ':::.'':.::::  :
 *      :..   ''::::::....':     ''::  :
 *      :::::.    ':::::   :     .. '' .
 *   .''::::::::... ':::.''   ..''  :.''''.
 *   :..:::'':::::  :::::...:''        :..:
 *   ::::::. '::::  ::::::::  ..::        .
 *   ::::::::.::::  ::::::::  :'':.::   .''
 *   ::: '::::::::.' '':::::  :.' '':  :
 *   :::   :::::::::..' ::::  ::...'   .
 *   :::  .::::::::::   ::::  ::::  .:'
 *    '::'  '':::::::   ::::  : ::  :
 *              '::::   ::::  :''  .:
 *               ::::   ::::    ..''
 *               :::: ..:::: .:''
 *                 ''''  '''''
 *
 *
 * AUTOMAD
 *
 * Copyright (c) 2021-2025 by Marc Anton Dahmen
 * https://marcdahmen.de
 *
 * Licensed under the MIT license.
 * https://automad.org/license
 */

namespace Automad\Models;

use Automad\Core\FileSystem;
use Automad\Core\FileUtils;
use Automad\Core\Messenger;
use Automad\Core\Str;
use Automad\Core\Text;

defined('AUTOMAD') or die('Direct access not permitted!');

/**
 * The Image controller.
 *
 * @author Marc Anton Dahmen
 * @copyright Copyright (c) 2021-2025 by Marc Anton Dahmen - https://marcdahmen.de
 * @license MIT license - https://automad.org/license
 */
class Image {
	/**
	 * Save an image.
	 *
	 * @param string $path
	 * @param string $name
	 * @param string $extension
	 * @param string $base64
	 * @param Messenger $Messenger
	 */
	public static function save(string $path, string $name, string $extension, string $base64, Messenger $Messenger): void {
		if (!in_array($extension, FileUtils::allowedFileTypes())) {
			$Messenger->setError(
				Text::get('unsupportedFileTypeError') . ' "' . $extension . '"'
			);

			return;
		}

		$data = preg_replace('/^data:image\/[a-z]+;base64,/', '', $base64) ?? '';
		$data = base64_decode($data);

		$name = $path . Str::slug($name) . '.' . $extension;

		if (FileSystem::write($name, $data) === false) {
			$Messenger->setError(Text::get('couldNotSaveError') . ' ' . $name);
		}
	}
}
